#region Copyright Syncfusion Inc. 2001 - 2017
// Copyright Syncfusion Inc. 2001 - 2017. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text.RegularExpressions;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using Syncfusion.DocToPDFConverter;
using Syncfusion.EJ.Export;
using Syncfusion.Pdf;

namespace DocumentExample
{
    public partial class _Default : Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            string exportDoc = "default.aspx/ExportToWord", exportPdf = "default.aspx/ExportToPDF";
            string RequestURL = HttpContext.Current.Request.Url.ToString();
            if (RequestURL.Contains(exportDoc)) ExportToWord();
            else if (RequestURL.Contains(exportPdf)) ExportToPDF();
        }

        public void ExportToPDF()
        {
            WordDocument document = GetDocument(Request[Request["rteid"] + "_inputval"]);
            DocToPDFConverter converter = new DocToPDFConverter();
            PdfDocument pdfDocument = converter.ConvertToPDF(document);
            pdfDocument.Save("Demo.pdf", HttpContext.Current.Response, HttpReadType.Save);
        }

        public WordDocument GetDocument(string htmlText)
        {
            WordDocument document = null;
            MemoryStream stream = new MemoryStream();
            StreamWriter writer = new StreamWriter(stream, System.Text.Encoding.Default);
            htmlText = htmlText.Replace("\"", "'");
            htmlText = htmlText.Replace("\r\n", "<br />");
            XmlConversion XmlText = new XmlConversion(htmlText);
            XhtmlConversion XhtmlText = new XhtmlConversion(XmlText);

            writer.Write(htmlText.ToString());
            writer.Flush();
            stream.Position = 0;
            document = new WordDocument(stream, FormatType.Html, XHTMLValidationType.None);
            return document;
        }

        protected void PrepareHeaders(WordDocument document)
        {
            document.Replace(new Regex("{Header}"), theCaption.InnerText);
            WParagraph paragraph = new WParagraph(document);
            paragraph.ParagraphFormat.HorizontalAlignment = Syncfusion.DocIO.DLS.HorizontalAlignment.Right;
            System.Drawing.Image i = System.Drawing.Image.FromFile(Server.MapPath(theLogo.ImageUrl));
            i = PicResizeByWidth(i, 260, 130);
            WPicture picture = (WPicture)paragraph.AppendPicture(i);

            TextBodyPart textBodyPart = new TextBodyPart(document);
            //Add the paragraph to  
            textBodyPart.BodyItems.Add(paragraph);
            //Replace the text with the TextBodyPart  
            document.Replace("{LogoPlatz}", textBodyPart, false, true);
        }

        protected void PrepareFooters(WordDocument document)
        {
            document.Replace(new Regex("{filename}"), theFilename.InnerText);
        }
        protected WordDocument GetTemplate()
        {
            string pUrl = theProjectLogo.ImageUrl;
            if (pUrl.ToLower().Contains("qsot"))
            {
                return new WordDocument("E:\\QMDOKU\\QSOT.docx");
            }
            else
            {
                return null;
            }
        }
        protected System.Drawing.Image PicResizeByWidth(System.Drawing.Image i, Int32 width, Int32 height)
        {
            decimal sizefactor = (decimal)width / i.Width;
            decimal sizefactorh = (decimal)height / i.Height;
            if (sizefactorh < sizefactor) sizefactor = sizefactorh;
            Int32 TrueWidth = Convert.ToInt32(sizefactor * (decimal)i.Width);
            Int32 TrueHeight = Convert.ToInt32(sizefactor * (decimal)i.Height);
            System.Drawing.Image NewImage = new System.Drawing.Bitmap(TrueWidth, TrueHeight);
            using (System.Drawing.Graphics g = System.Drawing.Graphics.FromImage(NewImage))
            {
                g.InterpolationMode = System.Drawing.Drawing2D.InterpolationMode.HighQualityBicubic;
                g.DrawImage(i, new Rectangle(0, 0, TrueWidth, TrueHeight));
            }
            //NewImage.Save("E:\\QMDoku\\temp.jpg", System.Drawing.Imaging.ImageFormat.Png);
            return NewImage;
        }

        private void ExportToWord()
        {
            WordDocument document = GetDocument(Request[Request["rteid"] + "_inputval"]);
            WordDocument d2 = GetTemplate();
            d2.EnsureMinimal();
            PrepareHeaders(d2);
            PrepareFooters(d2);
            foreach (WSection section in document.Sections)
            {
                foreach (TextBodyItem item in d2.Sections[0].HeadersFooters.Header.ChildEntities)
                {
                    section.HeadersFooters.Header.ChildEntities.Add(item.Clone());
                }

                foreach (TextBodyItem item in d2.Sections[0].HeadersFooters.Footer.ChildEntities)
                {
                    section.HeadersFooters.Footer.ChildEntities.Add(item.Clone());
                }
            }
            document.Save("Demo.docx", FormatType.Docx, HttpContext.Current.Response, HttpContentDisposition.Attachment);
        }

        protected void RTE1_ToolbarItemClick(object sender, Syncfusion.JavaScript.Web.RTEEventArgs e)
        {

        }
    }
}